<?php

/**
 * Ncmaz FSE functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Ncmaz FSE
 * @since Ncmaz FSE 1.0
 */


/** 
 *  Required Plugins
 */
require get_template_directory() . '/required-plugins.php';


// enqueuing block assets for both editor and front-end.
if (! function_exists('ncmaz_fse__enqueue_theme_styles')) :
	function ncmaz_fse__enqueue_theme_styles()
	{
		$theme_version = wp_get_theme()->get('Version');
		wp_enqueue_style(
			'mytheme-style',
			get_stylesheet_directory_uri() . '/assets/css/theme.css',
			array(),
			$theme_version
		);

		// Check if the Woocommerce plugin is active
		if (class_exists('WooCommerce')) {
			wp_enqueue_style(
				'ncmaz-fse-custom-woo-style',
				get_stylesheet_directory_uri() . '/assets/css/custom-woo.css',
				array(),
				$theme_version
			);
		}
	}
endif;
add_action('enqueue_block_assets', 'ncmaz_fse__enqueue_theme_styles');


//  tell WordPress which post formats to support by passing an array of formats like so:
function ncmaz_fse__post_formats_setup()
{
	add_theme_support('post-formats', array('aside', 'gallery', 'video', 'audio', 'link'));
}
add_action('after_setup_theme', 'ncmaz_fse__post_formats_setup');

/**
 * Register block styles.
 */

if (! function_exists('ncmaz_fse_block_styles')) :
	/**
	 * Register custom block styles
	 *
	 * @since Ncmaz FSE 1.0
	 * @return void
	 */
	function ncmaz_fse_block_styles()
	{

		register_block_style(
			'core/details',
			array(
				'name'         => 'arrow-icon-details',
				'label'        => __('Arrow icon', 'ncmaz-fse'),
				/*
				 * Styles for the custom Arrow icon style of the Details block
				 */
				'inline_style' => '
				.is-style-arrow-icon-details {
					padding-top: var(--wp--preset--spacing--10);
					padding-bottom: var(--wp--preset--spacing--10);
				}

				.is-style-arrow-icon-details summary {
					list-style-type: "\2193\00a0\00a0\00a0";
				}

				.is-style-arrow-icon-details[open]>summary {
					list-style-type: "\2192\00a0\00a0\00a0";
				}',
			)
		);
		register_block_style(
			'core/post-terms',
			array(
				'name'         => 'pill',
				'label'        => __('Pill', 'ncmaz-fse'),
				/*
				 * Styles variation for post terms
				 * https://github.com/WordPress/gutenberg/issues/24956
				 */
				'inline_style' => '
				.wp-block-post-terms.is-style-pill a,
				.wp-block-post-terms.is-style-pill span:not([class], [data-rich-text-placeholder]) {
					display: inline-block;
					background-color: var(--wp--preset--color--shadcn-accent);
					padding: 0.25rem 0.625rem;
					border-radius: 99px;
					font-weight: 500;
				}
				.wp-block-post-terms.is-style-pill {
					display: inline-flex;
					flex-wrap: wrap;
					row-gap: 0.5rem;
					column-gap: 0.125rem;
				}
				.wp-block-post-terms.is-style-pill a:hover {
					background-color: var(--wp--preset--color--shadcn-accent-lighter);
					text-decoration: none;
				}',
			)
		);
		register_block_style(
			'core/post-terms',
			array(
				'name'         => 'rounded',
				'label'        => __('Rounded', 'ncmaz-fse'),
				'inline_style' => '
				.wp-block-post-terms.is-style-rounded a,
				.wp-block-post-terms.is-style-rounded span:not([class], [data-rich-text-placeholder]) {
					display: inline-block;
					background-color: var(--wp--preset--color--shadcn-accent);
					padding: 0.25rem 0.625rem;
					border-radius: 8px;
					font-weight: 500;
				}
				.wp-block-post-terms.is-style-rounded {
					display: inline-flex;
					flex-wrap: wrap;
					row-gap: 0.5rem;
					column-gap: 0.125rem;
				}
				.wp-block-post-terms.is-style-rounded a:hover {
					background-color: var(--wp--preset--color--shadcn-accent-lighter);
					text-decoration: none;
				}',
			)
		);
		register_block_style(
			'core/post-terms',
			array(
				'name'         => 'underline',
				'label'        => __('Underline', 'ncmaz-fse'),
				'inline_style' => '.wp-block-post-terms.is-style-underline a{text-decoration: underline;}',
			)
		);
		register_block_style(
			'core/list',
			array(
				'name'         => 'checkmark-list',
				'label'        => __('Checkmark', 'ncmaz-fse'),
				/*
				 * Styles for the custom checkmark list block style
				 * https://github.com/WordPress/gutenberg/issues/51480
				 */
				'inline_style' => '
				ul.is-style-checkmark-list {
					list-style-type: "\2713";
				}

				ul.is-style-checkmark-list li {
					padding-inline-start: 1ch;
				}',
			)
		);
		register_block_style(
			'core/navigation-link',
			array(
				'name'         => 'arrow-link',
				'label'        => __('With arrow', 'ncmaz-fse'),
				/*
				 * Styles for the custom arrow nav link block style
				 */
				'inline_style' => '
				.is-style-arrow-link .wp-block-navigation-item__label:after {
					content: "\2197";
					padding-inline-start: 0.25rem;
					vertical-align: middle;
					text-decoration: none;
					display: inline-block;
				}',
			)
		);
		register_block_style(
			'core/heading',
			array(
				'name'         => 'asterisk',
				'label'        => __('With asterisk', 'ncmaz-fse'),
				'inline_style' => "
				.is-style-asterisk:before {
					content: '';
					width: 1.5rem;
					height: 3rem;
					background: var(--wp--preset--color--contrast-2, currentColor);
					clip-path: path('M11.93.684v8.039l5.633-5.633 1.216 1.23-5.66 5.66h8.04v1.737H13.2l5.701 5.701-1.23 1.23-5.742-5.742V21h-1.737v-8.094l-5.77 5.77-1.23-1.217 5.743-5.742H.842V9.98h8.162l-5.701-5.7 1.23-1.231 5.66 5.66V.684h1.737Z');
					display: block;
				}

				/* Hide the asterisk if the heading has no content, to avoid using empty headings to display the asterisk only, which is an A11Y issue */
				.is-style-asterisk:empty:before {
					content: none;
				}

				.is-style-asterisk:-moz-only-whitespace:before {
					content: none;
				}

				.is-style-asterisk.has-text-align-center:before {
					margin: 0 auto;
				}

				.is-style-asterisk.has-text-align-right:before {
					margin-left: auto;
				}

				.rtl .is-style-asterisk.has-text-align-left:before {
					margin-right: auto;
				}",
			)
		);
	}
endif;
add_action('init', 'ncmaz_fse_block_styles');

/**
 * Enqueue block stylesheets.
 */

if (! function_exists('ncmaz_fse_block_stylesheets')) :
	/**
	 * Enqueue custom block stylesheets
	 *
	 * @since Ncmaz FSE 1.0
	 * @return void
	 */
	function ncmaz_fse_block_stylesheets()
	{
		/**
		 * The wp_enqueue_block_style() function allows us to enqueue a stylesheet
		 * for a specific block. These will only get loaded when the block is rendered
		 * (both in the editor and on the front end), improving performance
		 * and reducing the amount of data requested by visitors.
		 *
		 * See https://make.wordpress.org/core/2021/12/15/using-multiple-stylesheets-per-block/ for more info.
		 */
		wp_enqueue_block_style(
			'core/button',
			array(
				'handle' => 'ncmaz-fse-button-style-outline',
				'src'    => get_parent_theme_file_uri('assets/css/button-outline.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/button-outline.css'),
			)
		);
		// WWooCommerce
		wp_enqueue_block_style(
			'woocommerce/mini-cart-contents',
			array(
				'handle' => 'woo-mini-cart-contents-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/mini-cart-contents.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/mini-cart-contents.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/mini-cart-products-table-block',
			array(
				'handle' => 'woo-mini-cart-products-table-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/mini-cart-products-table-block.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/mini-cart-products-table-block.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/mini-cart-footer-block',
			array(
				'handle' => 'woo-mini-cart-footer-block-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/mini-cart-footer-block.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/mini-cart-footer-block.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/mini-cart-title-block',
			array(
				'handle' => 'woo-mini-cart-title-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/mini-cart-title-block.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/mini-cart-title-block.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/cart-line-items-block',
			array(
				'handle' => 'woo-cart-line-items-block-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/cart-line-items-block.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/cart-line-items-block.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/cart-order-summary-block',
			array(
				'handle' => 'woo-cart-order-summary-block-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/cart-order-summary-block.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/cart-order-summary-block.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/product-price',
			array(
				'handle' => 'woo-product-price-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/product-price.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/product-price.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/product-template',
			array(
				'handle' => 'woo-product-template-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/product-template.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/product-template.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/product-button',
			array(
				'handle' => 'woo-product-button-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/product-button.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/product-button.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/add-to-cart-form',
			array(
				'handle' => 'woo-add-to-cart-form-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/add-to-cart-form.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/add-to-cart-form.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/product-details',
			array(
				'handle' => 'woo-product-details-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/product-details.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/product-details.css'),
			)
		);
		wp_enqueue_block_style(
			'woocommerce/mini-cart',
			array(
				'handle' => 'woo-mini-cart-style',
				'src'    => get_parent_theme_file_uri('assets/css/woocommerce/mini-cart.css'),
				'ver'    => wp_get_theme(get_template())->get('Version'),
				'path'   => get_parent_theme_file_path('assets/css/woocommerce/mini-cart.css'),
			)
		);
	}
endif;
add_action('init', 'ncmaz_fse_block_stylesheets');

/**
 * Register pattern categories.
 */

if (! function_exists('ncmaz_fse_pattern_categories')) :
	/**
	 * Register pattern categories
	 *
	 * @since Ncmaz FSE 1.0
	 * @return void
	 */
	function ncmaz_fse_pattern_categories()
	{

		register_block_pattern_category(
			'ncmaz_fse_page',
			array(
				'label'       => _x('Pages', 'Block pattern category', 'ncmaz-fse'),
				'description' => __('A collection of full page layouts.', 'ncmaz-fse'),
			)
		);
	}
endif;
add_action('init', 'ncmaz_fse_pattern_categories');


/**
 * Register block styles.
 */
if (! function_exists('ncmaz_fse_my_block_styles_2')) :
	function ncmaz_fse_my_block_styles_2()
	{
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'line-clamp-2',
				'label'        => __('Line Clamp 2', 'ncmaz-fse'),
				'inline_style' => "",
			)
		);
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'line-clamp-1',
				'label'        => __('Line Clamp 1', 'ncmaz-fse'),
				'inline_style' => "",
			)
		);
		register_block_style(
			'ncmazfse-block/term-name',
			array(
				'name'         => 'line-clamp-1',
				'label'        => __('Line Clamp 1', 'ncmaz-fse'),
				'inline_style' => "",
			)
		);
		register_block_style(
			'core/paragraph',
			array(
				'name'         => 'line-clamp-1',
				'label'        => __('Line Clamp 1', 'ncmaz-fse'),
				'inline_style' => "",
			)
		);

		register_block_style(
			'core/navigation-submenu',
			array(
				'name'         => 'rounded',
				'label'        => __('Rounded', 'ncmaz-fse'),
				'inline_style' => "
					.wp-block-navigation__responsive-container:not(.is-menu-open) .is-style-rounded .wp-block-navigation__submenu-container {
						border-radius: 8px; 
						box-shadow: 0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);
						padding: 0.5rem 0.25rem;
					}	
					.wp-block-navigation:not(.has-background) .is-style-rounded .wp-block-navigation__submenu-container {
						border: 1px solid var(--wp--preset--color--shadcn-border);
					}
					.wp-block-navigation .is-style-rounded .wp-block-navigation-item {
						background-color: unset;
						border-radius: 4px; 
					}
					.wp-block-navigation .wp-block-navigation__submenu-container .wp-block-navigation-item.open-on-click button.wp-block-navigation-item__content {
						padding: 0.5em 1em;
					}
					.wp-block-navigation .is-style-rounded .wp-block-navigation-item > a.wp-block-navigation-item__content:hover {
						text-decoration: none;
					}
					.wp-block-navigation .is-style-rounded .wp-block-navigation-item:hover {
						background-color: var(--wp--preset--color--shadcn-accent);
					}
				",
			)
		);
	}
endif;
add_action('init', 'ncmaz_fse_my_block_styles_2');


//  after_switch_theme hook is triggered when the theme is activated.
// Register custom demo pages and focus on the page temaplate for each page.
if (! function_exists('ncmaz_fse_handle_theme_after_switch_theme')) :
	function ncmaz_fse_handle_theme_after_switch_theme()
	{
		if (get_option('ncmaz_fse_after_switch_theme_created')) {
			return;
		}

		// Create demo pages
		$demo_pages = [
			[
				'slug' => 'wishlist',
				'title' => 'Wishlist',
				'template' => 'page-no-title.html',
				'content' => '<!-- wp:pattern {"slug":"ncmaz-fse/page-wishlist"} /-->',
			],
			[
				'slug' => 'reading-list',
				'title' => 'Reading List',
				'template' => 'page-no-title.html',
				'content' => '<!-- wp:pattern {"slug":"ncmaz-fse/page-reading-list"} /-->',
			],
			[
				'slug' => 'contact',
				'title' => 'Contact',
				'template' => 'page-no-title.html',
				'content' => '<!-- wp:pattern {"slug":"ncmaz-fse/page-contact"} /-->'
			],
			[
				'slug' => 'about-us',
				'title' => 'About Us',
				'template' => 'page-no-title.html',
				'content' => '<!-- wp:pattern {"slug":"ncmaz-fse/page-about"} /-->'
			],
			[
				'slug' => 'my-account',
				'title' => 'My Account',
				'template' => 'page-1000px-wide.html',
				'content' => ''
			],
		];
		foreach ($demo_pages as $demo_page) {
			// Kiểm tra xem trang đã tồn tại chưa
			$page = get_page_by_path($demo_page['slug']);
			if (!$page) {
				// Tạo trang mới
				$page_id = wp_insert_post(
					array(
						'post_title'    => $demo_page['title'],
						'post_content'  =>  $demo_page['content'],
						'post_status'   => 'publish',
						'post_type'     => 'page',
						'post_name'     => $demo_page['slug'],
					)
				);
				if ($page_id && !is_wp_error($page_id)) {
					// Đặt template cho trang
					update_post_meta($page_id, '_wp_page_template', $demo_page['template']);
				}
			} else {
				// Đặt template cho trang
				update_post_meta($page->ID, '_wp_page_template', $demo_page['template']);
			}
		}

		// check total current pb posts and create demo posts
		$published_posts = wp_count_posts()->publish;
		if ($published_posts < 7) {
			require_once(ABSPATH . 'wp-admin/includes/taxonomy.php');

			// Create demo posts and create demo categories
			$demo_posts  = [
				[
					'title' => 'Demo article - default single template',
					'category' => 'Sport',
				],
				[
					'title' => 'Demo article - single with sidebar template',
					'category' => 'Education',
					'template' => 'single-with-sidebar.html'
				],
				[
					'title' => 'Demo article - single 1 template',
					'category' => 'Travel',
					'template' => 'single-1.html'
				],
				[
					'title' => 'Demo article - single 2 with sidebar template',
					'category' => 'Books',
					'template' => 'single-2-with-sidebar.html'
				],
				[
					'title' => 'Demo article - single with sidebar template',
					'category' => 'Smart phones',
					'template' => 'single-with-sidebar.html'
				],
				[
					'title' => 'Demo article - default single template',
					'category' => 'Life styles',
				],
				[
					'title' => 'Demo article - single 2 with sidebar template',
					'category' => 'Technology',
					'template' => 'single-2-with-sidebar.html'
				],
			];

			// Upload a demo image to WordPress media library
			$file_content = file_get_contents(get_template_directory() . '/assets/images/museum.webp');
			$attach_id = ncmaz_fse_upload_image_to_wordpress('museum.webp', $file_content);

			foreach ($demo_posts as $demo_post) {
				// Create demo categories
				$cat_id = wp_create_category($demo_post['category']);
				$cat_featured_image = get_term_meta($cat_id, 'featured_image', true);
				if (! $cat_featured_image) {
					update_term_meta($cat_id, 'featured_image', $attach_id);
				}

				// Create demo posts
				$post_id = wp_insert_post(
					array(
						'post_title'    => $demo_post['title'],
						'post_content'  => $demo_post['title'],
						'post_excerpt'  => 'Immerse yourself in the world of literature with our curated collection of books. From bestsellers to hidden gems, our assortment caters to a variety of interests and genres.',
						'post_status'   => 'publish',
						'post_type'     => 'post',
						'post_category' => array($cat_id),
						'tags_input'    => ['Ncmaz', 'Fse', 'Theme'],
					)
				);

				if ($post_id && !is_wp_error($post_id)) {

					if (isset($demo_post['template'])) {
						update_post_meta($post_id, '_wp_page_template', $demo_post['template']);
					}

					if (!is_wp_error($attach_id)) {
						set_post_thumbnail($post_id, $attach_id);
					}
				}
			}
		}

		// Set a flag to prevent this code from running again
		update_option('ncmaz_fse_after_switch_theme_created', true);
	}
endif;
add_action('after_switch_theme', 'ncmaz_fse_handle_theme_after_switch_theme');

if (!function_exists('ncmaz_fse_upload_image_to_wordpress')) :
	function ncmaz_fse_upload_image_to_wordpress($file_name, $file_content)
	{
		// Đảm bảo các hàm cần thiết được load
		require_once(ABSPATH . 'wp-admin/includes/file.php');
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Kiểm tra loại file
		$file_type = wp_check_filetype($file_name);
		if (!$file_type['type']) {
			return new WP_Error('invalid_file_type', __('Invalid file type'));
		}

		// Tạo tên file duy nhất
		$file_name = wp_unique_filename(wp_upload_dir()['path'], $file_name);

		// Upload file vào thư mục uploads
		$upload = wp_upload_bits($file_name, null, $file_content);

		if ($upload['error']) {
			return new WP_Error('upload_error', $upload['error']);
		}

		// Tạo attachment data
		$attachment = array(
			'post_mime_type' => $file_type['type'],
			'post_title'     => preg_replace('/\.[^.]+$/', '', $file_name),
			'post_content'   => '',
			'post_status'    => 'inherit'
		);

		// Chèn attachment vào cơ sở dữ liệu
		$attach_id = wp_insert_attachment($attachment, $upload['file']);

		if (is_wp_error($attach_id)) {
			return $attach_id;
		}

		// Tạo metadata cho attachment
		$attach_data = wp_generate_attachment_metadata($attach_id, $upload['file']);
		wp_update_attachment_metadata($attach_id, $attach_data);

		return $attach_id;
	}
endif;
